============
*pyscrapers*
============

.. image:: https://img.shields.io/pypi/v/pyscrapers

.. image:: https://img.shields.io/github/license/veltzer/pyscrapers

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pyscrapers

author: Mark Veltzer

version: 0.0.66

	Mark Veltzer <mark.veltzer@gmail.com>, Copyright © 2016, 2017, 2018, 2019, 2020, 2021, 2022
